---
permalink: /support
fbcontact: true
---

# Unterstützung

Da dies nur ein Freizeitprojekt ist, bin ich auf jegliche Unterstützung angewiesen. Deshalb würde ich mich sehr über Unterstützung freuen!

<a href="https://www.patreon.com/bePatron?u=28808035" data-patreon-widget-type="become-patron-button">Werde ein Patreon!</a>
<script async src="https://c6.patreon.com/becomePatronButton.bundle.js"></script>

Wenn Sie keinen Patreon Account haben und mich trotzdem unterstützen wollen, können Sie mich gerne [kontaktieren](<{{ site.kontakt_url }}>). Schon mal jetzt vielen Dank für Ihre Unterstützung!

## Zurück

[Zur Startseite](./README.md) - [Zum Handbuch](./manual/README.md)
